@@ -406,7 +406,11 @@ def call_method(metaObject, args, unknown_args, colorPrint):
             else:
                 break
     except VariableError as e:
-        _print(e)
+        
+        if hasattr(e, "message"):
+            _print(e.message)
+        else:
+            _print(e)
         return None
     #for ReturnedMessage in method_result:
     #    if ReturnedMessage.type and ReturnedMessage.type != "pid":
