@@ -455,9 +455,9 @@ def display_error(error, args, groups):
                     __print.bold.foreground(TextState.Colors.WHITE)("*")
                 __print("\n")
     elif error.type != "commonerror":
-        colorPrint.printERROR(params_text % error)
+        colorPrint.printERROR(params_text % error.message)
     else:
-        colorPrint.printWARNING(error)
+        colorPrint.printWARNING(error.message)
 
 
 def check_result_msg(method_result, view, input_error_dict=None, args=None):
